powered by
plot most variable k peaks (default k = 100) among all samples
heatmap_var_peaks(results, heatmap.peak.count = 100, ...)
ggplot object
cinaR result object
number of peaks to be plotted. If number of peaks are less than k then all peaks will be used.
additional arguments for heatmap function, for more info `?pheatmap`
library(cinaR) data(atac_seq_consensus_bm) # calls 'bed' # creating dummy results results <- NULL results[["cp"]] <- bed[,c(4:25)] heatmap_var_peaks(results)
Run the code above in your browser using DataLab